@@ -2,7 +2,7 @@ import os, ConfigParser, cgi, re
 import glob
 from os.path import join, isfile, abspath, splitext, expanduser, exists
 from gettext import gettext as _
-
+from deskbar.defs import VERSION
 import gobject
 import gtk
 import deskbar, deskbar.Indexer, deskbar.Utils
@@ -13,14 +13,22 @@ HANDLERS = {
 	"ProgramsHandler" : {
 		"name": _("Programs"),
 		"description": _("Launch a program by its name and/or description"),
+		"version": VERSION,
 	},
 	"GnomeDictHandler" : {
 		"name": _("Dictionary"),
 		"description": _("Look up word definitions in the dictionary"),
+		"version": VERSION,
 	},
 	"GnomeSearchHandler" : {
 		"name": _("Files and Folders Search"),
 		"description": _("Find files and folders by searching for a name pattern"),
+		"version": VERSION,
+	},
+	"DevhelpHandler" : {
+		"name": _("Developer Documentation"),
+		"description": _("Search Devhelp for a function name"),
+		"version": VERSION,
 	},
 }
 
@@ -62,7 +70,7 @@ class GenericProgramMatch(deskbar.Match.Match):
 			#self._desktop.launch(text.split(" "), deskbar.gnomedesktop.LAUNCH_APPEND_PATHS|deskbar.gnomedesktop.LAUNCH_ONLY_ONE)
 		else:
 			self._desktop.launch([])
-	
+
 	def get_category(self):
 		return "actions"
 	
@@ -93,6 +101,14 @@ class GnomeSearchMatch(GenericProgramMatch):
 	def get_verb(self):
 		return _("Search for file names like %s") % "<b>%(text)s</b>"
 
+class DevhelpMatch(GenericProgramMatch):
+	def __init__(self, backend, use_arg=True, **args):
+		GenericProgramMatch.__init__(self, backend, use_arg=use_arg, **args)
+		self._args = ["-s"]
+		
+	def get_verb(self):
+		return _("Search in Devhelp for %s") % "<b>%(text)s</b>"
+
 class SpecialProgramHandler(deskbar.Handler.Handler):
 	def __init__(self, desktop, icon=gtk.STOCK_EXECUTE):
 		deskbar.Handler.Handler.__init__(self, icon)
@@ -137,6 +153,18 @@ class GnomeSearchHandler(SpecialProgramHandler):
 					desktop=desktop,
 					desktop_file=f)
 		
+class DevhelpHandler(SpecialProgramHandler):
+	def __init__(self):
+		SpecialProgramHandler.__init__(self, "devhelp.desktop", "devhelp")
+	
+	def create_match(self, desktop, f):
+		return DevhelpMatch(
+					self,
+					name=cgi.escape(desktop.get_localestring(deskbar.gnomedesktop.KEY_NAME)),
+					icon=desktop.get_string(deskbar.gnomedesktop.KEY_ICON),
+					desktop=desktop,
+					desktop_file=f)
+		
 class ProgramsHandler(deskbar.Handler.Handler):
 	def __init__(self):
 		deskbar.Handler.Handler.__init__(self, gtk.STOCK_EXECUTE)
