@@ -1,8 +1,9 @@
+from deskbar.Utils import strip_html
 from gettext import gettext as _
-
+from deskbar.defs import VERSION
 import urllib, cgi
 import gnomevfs
-import deskbar.Handler
+import deskbar.Handler, deskbar
 import xml.dom.minidom
 
 YAHOO_API_KEY = 'deskbar-applet'
@@ -14,12 +15,13 @@ HANDLERS = {
 	"YahooHandler" : {
     	"name": _("Yahoo! Search"),
     	"description": _("Search Yahoo! as you type"),
+    	"version": VERSION,
 	}
 }
 
 class YahooMatch(deskbar.Match.Match):
-	def __init__(self, handler, name, url, **args):
-		deskbar.Match.Match.__init__ (self, handler, name=name, **args)
+	def __init__(self, handler, url=None, **args):
+		deskbar.Match.Match.__init__ (self, handler, **args)
 		self.url = url
 
 	def get_verb(self):
@@ -39,10 +41,7 @@ class YahooHandler(deskbar.Handler.AsyncHandler):
 		deskbar.Handler.AsyncHandler.__init__(self, "yahoo.png")
 		self.server = None
 
-	def query(self, qstring, qmax):
-		# Just to ensure we don't bork anything
-		qmax = min (qmax, MAX_QUERIES)
-
+	def query(self, qstring):
 		# Delay before we query so we *don't* make four queries
 		# "s", "sp", "spa", "spam".
 		self.check_query_changed (timeout=QUERY_DELAY)
@@ -53,7 +52,7 @@ class YahooHandler(deskbar.Handler.AsyncHandler):
 			urllib.urlencode(
 				{'appid': YAHOO_API_KEY,
 				'query': qstring,
-				'results': qmax}))
+				'results': 15}))
 		dom = xml.dom.minidom.parse(stream)
 		print 'Got yahoo answer for:', qstring
 		
@@ -62,11 +61,10 @@ class YahooHandler(deskbar.Handler.AsyncHandler):
 		# better check if we're still valid
 		matches = [
 			YahooMatch (self, 
-					cgi.escape(r.getElementsByTagName("Title")[0].firstChild.data.encode('utf8')),
-					r.getElementsByTagName("ClickUrl")[0].firstChild.data.encode('utf8')
+					name=cgi.escape(strip_html(r.getElementsByTagName("Title")[0].firstChild.data.encode('utf8'))),
+					url=r.getElementsByTagName("ClickUrl")[0].firstChild.data.encode('utf8')
 			)
-			for r in dom.getElementsByTagName("Result")[:qmax-1]
-			]
+			for r in dom.getElementsByTagName("Result")]
 		self.check_query_changed ()
 		print "Returning yahoo answer for:", qstring
 		return matches
